@@ -22,11 +22,11 @@ Virani - PCAP retrieval for a FPC setup writing to PCAP files.
 
 =head1 VERSION
 
-Version 1.0.1
+Version 1.1.0
 
 =cut
 
-our $VERSION = '1.0.1';
+our $VERSION = '1.1.0';
 
 =head1 SYNOPSIS
 
@@ -103,6 +103,12 @@ Initiates the object.
     - verbose_to_syslog :: Send verbose items to syslog. This is used by mojo-virani.
         Default :: 0
 
+    - pcap_glob :: The glob to use for matching files.
+        Default :: *.pcap*
+
+    - ts_is_unixtime :: The timestamp is unixtime and does not requires additional processing.
+        Default :: 1
+
     - verbose :: Print verbose info.
         Default :: 1
 
@@ -129,6 +135,8 @@ For sets, the following keys are usable, of which only path is required.
 
     - type :: The default filter type to use with this set.
 
+    - ts_is_unixtime :: The timestamp is unixtime and does not requires additional processing.
+
 =cut
 
 sub new {
@@ -146,6 +154,8 @@ sub new {
 		verbose           => 1,
 		type              => 'tcpdump',
 		padding           => 5,
+		ts_is_unixtime    => 1,
+		pcap_glob         => '*.pcap*',
 		sets              => {
 			default => {
 				path => '/var/log/daemonlogger',
@@ -169,9 +179,9 @@ sub new {
 
 	# real in basic values
 	my @real_in = (
-		'apikey',           'default_set',       'cache',   'padding',
-		'default_max_time', 'verbose_to_syslog', 'verbose', 'auth_by_IP_only',
-		'type'
+		'apikey',           'default_set',       'cache',     'padding',
+		'default_max_time', 'verbose_to_syslog', 'verbose',   'auth_by_IP_only',
+		'type',             'ts_is_unixtime',    'pcap_glob', 'default_regex'
 	);
 	for my $key (@real_in) {
 		if ( defined( $opts{$key} ) ) {
@@ -753,6 +763,10 @@ The return is a hash reference that includes the following keys.
 
     - pcap_count :: A count of used PCAPs.
 
+    - pcap_glob :: The value of pcap_glob used.
+
+    - ts_is_unixtime :: The value of ts_is_unixtime used.
+
     - failed :: A hash of PCAPs that failed. PCAP path as key and value being the reason.
 
     - failed_count :: A count of failed PCAPs.
@@ -804,6 +818,12 @@ sub get_pcap_local {
 	# start of the request
 	my $req_start = localtime;
 
+	# if set is undef or blank, use the default
+	if ( !defined( $opts{set} ) || $opts{set} eq '' ) {
+		$opts{set} = $self->get_default_set;
+	}
+	$self->verbose( 'info', 'Set: ' . $opts{set} );
+
 	# make sure we have something for type and check to make sure it is sane
 	if ( !defined( $opts{type} ) ) {
 		$opts{type} = $self->{type};
@@ -812,6 +832,23 @@ sub get_pcap_local {
 		}
 	}
 
+	# figure out what to use for $ts_is_unixtime
+	my $ts_is_unixtime;
+	if ( defined( $self->{sets}{ $opts{set} }{ts_is_unixtime} ) ) {
+		$ts_is_unixtime = $self->{sets}{ $opts{set} }{ts_is_unixtime};
+	} else {
+		$ts_is_unixtime = $self->{ts_is_unixtime};
+	}
+
+	# figure out what to use for $pcap_glob
+	my $pcap_glob;
+	if ( defined( $self->{sets}{ $opts{set} }{pcap_glob} ) ) {
+		$pcap_glob = $self->{sets}{ $opts{set} }{pcap_glob};
+	} else {
+		$pcap_glob = $self->{pcap_glob};
+	}
+	$self->verbose( 'info', 'PCAP Glob: ' . $pcap_glob );
+
 	# check it here incase the config includes something off
 	if ( !$self->check_type( $opts{type} ) ) {
 		die( 'type "' . $opts{type} . '" is not a supported type, tcpdump or tshark,' );
@@ -843,11 +880,6 @@ sub get_pcap_local {
 	}
 	$self->verbose( 'info', 'no_cache: ' . $opts{no_cache} );
 
-	if ( !defined( $opts{set} ) || $opts{set} eq '' ) {
-		$opts{set} = $self->get_default_set;
-	}
-	$self->verbose( 'info', 'Set: ' . $opts{set} );
-
 	# make sure the set exists
 	if ( !defined( $self->{sets}->{ $opts{set} } ) ) {
 		die( 'The set "' . $opts{set} . '" is not defined' );
@@ -881,14 +913,11 @@ sub get_pcap_local {
 
 	# if applicable return the cache file
 	my $return_cache = 0;
-	if (
-		   defined( $opts{file} )
+	if (   defined( $opts{file} )
 		&& $opts{file} ne $cache_file
 		&& !$opts{no_cache}
 		&& -f $cache_file
-		&& -f $cache_file . '.json'
-
-		)
+		&& -f $cache_file . '.json' )
 	{
 		$return_cache = 1;
 	} elsif ( !defined( $opts{file} ) && !$opts{no_cache} && -f $cache_file && -f $cache_file . '.json' ) {
@@ -933,7 +962,7 @@ sub get_pcap_local {
 	}
 
 	# get the pcaps
-	my @pcaps = File::Find::Rule->file()->name("*.pcap*")->in($set_path);
+	my @pcaps = File::Find::Rule->file()->name($pcap_glob)->in($set_path);
 
 	# get the ts_regexp to use
 	my $ts_regexp;
@@ -942,37 +971,41 @@ sub get_pcap_local {
 	} else {
 		$ts_regexp = $self->{default_regex};
 	}
+	$self->verbose( 'info', 'Timestamp Regexp: ' . $ts_regexp );
 
 	my $to_check = File::Find::IncludesTimeRange->find(
-		items => \@pcaps,
-		start => $start,
-		end   => $end,
-		regex => $ts_regexp,
+		items          => \@pcaps,
+		start          => $start,
+		end            => $end,
+		regex          => $ts_regexp,
+		ts_is_unixtime => $ts_is_unixtime,
 	);
 
 	# The return hash and what will be used for the cache JSON
 	# req_end stuff set later
 	my $to_return = {
-		pcaps         => $to_check,
-		pcap_count    => 0,
-		failed        => {},
-		failed_count  => 0,
-		success_count => 0,
-		path          => $cache_file,
-		filter        => $opts{filter},
-		total_size    => 0,
-		failed_size   => 0,
-		success_size  => 0,
-		tmp_size      => 0,
-		final_size    => 0,
-		type          => $opts{type},
-		padding       => $opts{padding},
-		start_s       => $opts{start}->epoch,
-		start         => $opts{start}->strftime('%Y-%m-%dT%H:%M:%S%z'),
-		end_s         => $opts{end}->epoch,
-		end           => $opts{end}->strftime('%Y-%m-%dT%H:%M:%S%z'),
-		req_start     => $req_start->strftime('%Y-%m-%dT%H:%M:%S%z'),
-		req_start_s   => $req_start->epoch,
+		pcaps          => $to_check,
+		pcap_glob      => $pcap_glob,
+		pcap_count     => 0,
+		failed         => {},
+		failed_count   => 0,
+		success_count  => 0,
+		path           => $cache_file,
+		filter         => $opts{filter},
+		total_size     => 0,
+		failed_size    => 0,
+		success_size   => 0,
+		tmp_size       => 0,
+		final_size     => 0,
+		type           => $opts{type},
+		padding        => $opts{padding},
+		start_s        => $opts{start}->epoch,
+		start          => $opts{start}->strftime('%Y-%m-%dT%H:%M:%S%z'),
+		end_s          => $opts{end}->epoch,
+		end            => $opts{end}->strftime('%Y-%m-%dT%H:%M:%S%z'),
+		req_start      => $req_start->strftime('%Y-%m-%dT%H:%M:%S%z'),
+		req_start_s    => $req_start->epoch,
+		ts_is_unixtime => $ts_is_unixtime,
 	};
 
 	# used for tracking the files to cleanup
@@ -1228,11 +1261,17 @@ With daemonlogger setup along the lines of like below...
 The following can be made available via mojo-varini or locally via varini with the set name of
 default as below.
 
-    default_set='default'
     allowed_subnets=["192.168.14.0/23", "127.0.0.1/8"]
     [sets.default]
     path='/var/log/daemonlogger'
-    regex='(?<timestamp>\d\d\d\d\d\d+)(\.pcap|(?<subsec>\.\d+)\.pcap)$'
+
+If you want to use 'init/freebsd' to start mojo-virani, you just need to copy it
+it to '/usr/local/etc/rc.d/virani' and add the following or the like to '/etc/rc.conf'.
+
+    virani_enable="YES"
+    virani_flags="daemon -m production -l http://127.0.0.1:8080 -l http://192.168.14.1:8080"
+
+See the script for information on the various possible config args for it.
 
 =head1 AUTHOR
 
